==> nextcloud-app-calendar-1:4.1.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/si.js <==
OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "පරිශීලක-සැසිය අනපේක්ෂිත ලෙස කල් ඉකුත් විය",
    "Provided email-address is not valid" : "සපයා ඇති විද්‍යුත් තැපැල් ලිපිනය වලංගු නොවේ",
    "Hello," : "ආයුබෝවන්,",
    "Cheers!" : "ජයවේවා!",
    "Confirm" : "තහවුරු කරන්න",
    "Date:" : "දිනය:",
    "Where:" : "කොහේද:",
    "Calendar" : "දින දර්ශනය",
    "A Calendar app for Nextcloud" : "නෙක්ස්ට් ක්ලවුඩ් සඳහා දින දර්ශන යෙදුමකි",
    "Previous day" : "පසුගිය දිනය",
    "Previous week" : "පසුගිය සතිය",
    "Previous month" : "පසුගිය මාසය",
    "Next day" : "ඊළඟ දිනය",
    "Next week" : "ඊළඟ සතිය",
    "Next month" : "ඊළඟ මාසය",
    "Today" : "අද",
    "Day" : "දිනය",
    "Week" : "සතිය",
    "Month" : "මාසය",
    "List" : "ලැයිස්තුව",
    "Preview" : "පෙරදසුන",
    "Copy link" : "සබැඳිය පිටපත් කරන්න",
    "Edit" : "සංස්කරණය",
    "Untitled calendar" : "නිර්ණාමික දින දර්ශනය",
    "Edit name" : "නම සංස්කරණය",
    "Saving name …" : "සුරැකීමේ වර්ණය …",
    "Edit color" : "වර්ණය සංස්කරණය",
    "Saving color …" : "සුරැකීමේ වර්ණය …",
    "Copy private link" : "පුද්. සබැඳිය පිටපත් කරන්න",
    "Name" : "නම",
    "Restore" : "ප්‍රතිෂ්ථාපනය",
    "Filename" : "ගොනු නාමය",
    "Cancel" : "අවලංගු කරන්න",
    "Actions" : "ක්‍රියාමාර්ග",
    "Location" : "ස්ථානය",
    "Description" : "විස්තරය",
    "Duration" : "කාල සීමාව",
    "Add" : "එකතු කරන්න",
    "Monday" : "සඳුදා",
    "Tuesday" : "අඟහරුවාදා",
    "Wednesday" : "බදාදා",
    "Thursday" : "බ්‍රහස්පතින්දා",
    "Friday" : "සිකුරාදා",
    "Saturday" : "සෙනසුරාදා",
    "Sunday" : "ඉරිදා",
    "Save" : "සුරකින්න",
    "Update" : "යාවත්කාල",
    "Email" : "විද්‍යුත් තැපෑල",
    "Available" : "ඇත",
    "Busy" : "කාර්යබහුලයි",
    "Unknown" : "නොදන්නා",
    "Accept" : "පිළිගන්න",
    "Decline" : "ප්‍රතික්ෂේප",
    "More" : "තව",
    "Time:" : "වේලාව:",
    "Personal" : "පුද්ගලික",
    "Details" : "විස්තර",
    "Close" : "වසන්න",
    "Anniversary" : "සංවත්සරය",
    "Daily" : "දිනපතා",
    "Weekly" : "සතිපතා",
    "Next" : "ඊළඟ",
    "Year" : "වර්ෂය",
    "Other" : "වෙනත්",
    "Mail" : "තැපෑල",
    "Birthday" : "උපන් දිනය"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1:5.3.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/si.js <==
OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "පරිශීලක-සැසිය අනපේක්ෂිත ලෙස කල් ඉකුත් විය",
    "Provided email-address is not valid" : "සපයා ඇති විද්‍යුත් තැපැල් ලිපිනය වලංගු නොවේ",
    "Hello," : "ආයුබෝවන්,",
    "Cheers!" : "ජයවේවා!",
    "Calendar" : "දින දර්ශනය",
    "Confirm" : "තහවුරු කරන්න",
    "Description:" : "විස්තරය",
    "Date:" : "දිනය:",
    "Where:" : "කොහේද:",
    "A Calendar app for Nextcloud" : "නෙක්ස්ට් ක්ලවුඩ් සඳහා දින දර්ශන යෙදුමකි",
    "Previous day" : "පසුගිය දිනය",
    "Previous week" : "පසුගිය සතිය",
    "Previous month" : "පසුගිය මාසය",
    "Next day" : "ඊළඟ දිනය",
    "Next week" : "ඊළඟ සතිය",
    "Next month" : "ඊළඟ මාසය",
    "Today" : "අද",
    "Day" : "දිනය",
    "Week" : "සතිය",
    "Month" : "මාසය",
    "Year" : "වර්ෂය",
    "List" : "ලැයිස්තුව",
    "Preview" : "පෙරදසුන",
    "Copy link" : "සබැඳිය පිටපත් කරන්න",
    "Edit" : "සංස්කරණය",
    "Untitled calendar" : "නිර්ණාමික දින දර්ශනය",
    "Name" : "නම",
    "Restore" : "ප්‍රතිෂ්ථාපනය",
    "Save" : "සුරකින්න",
    "Filename" : "ගොනු නාමය",
    "Cancel" : "අවලංගු කරන්න",
    "Actions" : "ක්‍රියාමාර්ග",
    "Update" : "යාවත්කාල",
    "Location" : "ස්ථානය",
    "Description" : "විස්තරය",
    "Duration" : "කාල සීමාව",
    "Add" : "එකතු කරන්න",
    "Monday" : "සඳුදා",
    "Tuesday" : "අඟහරුවාදා",
    "Wednesday" : "බදාදා",
    "Thursday" : "බ්‍රහස්පතින්දා",
    "Friday" : "සිකුරාදා",
    "Saturday" : "සෙනසුරාදා",
    "Sunday" : "ඉරිදා",
    "Back" : "ආපසු",
    "Email" : "විද්‍යුත් තැපෑල",
    "Available" : "ඇත",
    "Busy" : "කාර්යබහුලයි",
    "Unknown" : "නොදන්නා",
    "Accept" : "පිළිගන්න",
    "Decline" : "ප්‍රතික්ෂේප",
    "Time:" : "වේලාව:",
    "Personal" : "පුද්ගලික",
    "Close" : "වසන්න",
    "Anniversary" : "සංවත්සරය",
    "Daily" : "දිනපතා",
    "Weekly" : "සතිපතා",
    "Other" : "වෙනත්",
    "Details" : "විස්තර"
},
"nplurals=2; plural=(n != 1);");
